@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -326,6 +326,7 @@ void DirectShowPlayerService::doSetUrlSource(QMutexLocker *locker)
         case VFW_E_NOT_FOUND:
             m_error = QMediaPlayer::ResourceError;
             m_errorString = QString();
+            break;
         default:
             m_error = QMediaPlayer::ResourceError;
             m_errorString = QString();
@@ -474,6 +475,7 @@ void DirectShowPlayerService::doRender(QMutexLocker *locker)
                 case VFW_E_UNSUPPORTED_STREAM:
                     m_error = QMediaPlayer::FormatError;
                     m_errorString = QString();
+                    break;
                 default:
                     m_error = QMediaPlayer::ResourceError;
                     m_errorString = QString();
@@ -1318,6 +1320,12 @@ void DirectShowPlayerService::run()
             m_executingTask = ReleaseGraph;
 
             doReleaseGraph(&locker);
+            //if the graph is released, we should not process other operations later
+            if (m_pendingTasks & Shutdown) {
+                m_pendingTasks = 0;
+                return;
+            }
+            m_pendingTasks = 0;
         } else if (m_pendingTasks & Shutdown) {
             return;
         } else if (m_pendingTasks & ReleaseAudioOutput) {
