@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -227,7 +227,7 @@ void S60MediaPlayerSession::load(QUrl url)
         if(m_stream)
             doLoadUrlL(QString2TPtrC(url.toString()));
         else
-            doLoadL(QString2TPtrC(QDir::toNativeSeparators(url.toLocalFile()))));
+            doLoadL(QString2TPtrC(QDir::toNativeSeparators(QDir::cleanPath(url.toLocalFile())))));
     setError(err);
 
     DP0("S60MediaPlayerSession::load ---");
@@ -284,6 +284,7 @@ void S60MediaPlayerSession::pause()
     setState(QMediaPlayer::PausedState);
     stopProgressTimer();
     TRAP_IGNORE(doPauseL());
+    m_play_requested = false;
 
     DP0("S60MediaPlayerSession::pause ---");
 }
@@ -333,6 +334,7 @@ void S60MediaPlayerSession::reset()
     setPosition(0);
     setState(QMediaPlayer::StoppedState);
     setMediaStatus(QMediaPlayer::UnknownMediaStatus);
+    setPosition(0);
 
     DP0("S60MediaPlayerSession::reset ---");
 }
@@ -773,6 +775,8 @@ QMediaPlayer::Error S60MediaPlayerSession::fromSymbianErrorToMultimediaError(int
         case KErrServerBusy:
         case KErrCompletion:  
         case KErrBadPower:    
+        case KErrMMInvalidProtocol:
+        case KErrMMInvalidURL:
             return QMediaPlayer::ResourceError;
         
         case KErrMMPartialPlayback:   
@@ -791,8 +795,6 @@ QMediaPlayer::Error S60MediaPlayerSession::fromSymbianErrorToMultimediaError(int
         case KErrMMServerSocket:
         case KErrMMServerNotSupported:
         case KErrMMUDPReceive:
-        case KErrMMInvalidProtocol:
-        case KErrMMInvalidURL:
         case KErrMMMulticast:
         case KErrMMProxyServer:
         case KErrMMProxyServerNotSupported:
@@ -865,7 +867,9 @@ void S60MediaPlayerSession::setError(int error, const QString &errorString, bool
 
     emit this->error(mediaError, symbianError);
 
-    if (mediaError !=QMediaPlayer::NoError) {
+    if (m_error == KErrInUse) {
+        pause();
+    } else if (mediaError != QMediaPlayer::NoError) {
         m_play_requested = false;
         setMediaStatus(QMediaPlayer::InvalidMedia);
         stop();
