@@ -418,7 +418,7 @@ Q_DEFINE_LATIN1_CONSTANT(QContactManager::ParameterValueOnlyOtherProcesses, "Onl
  */
 QContactManager::Error QContactManager::error() const
 {
-    return d->m_error;
+    return d->m_lastError;
 }
 
 /*!
@@ -432,7 +432,7 @@ QContactManager::Error QContactManager::error() const
  */
 QMap<int, QContactManager::Error> QContactManager::errorMap() const
 {
-    return d->m_errorMap;
+    return d->m_lastErrorMap;
 }
 
 /*!
@@ -440,9 +440,8 @@ QMap<int, QContactManager::Error> QContactManager::errorMap() const
  */
 QList<QContactLocalId> QContactManager::contactIds(const QList<QContactSortOrder>& sortOrders) const
 {
-    d->m_error = QContactManager::NoError;
-    d->m_errorMap.clear();
-    return d->m_engine->contactIds(QContactFilter(), sortOrders, &d->m_error);
+    QContactManagerSyncOpErrorHolder h(this);
+    return d->m_engine->contactIds(QContactFilter(), sortOrders, &h.error);
 }
 
 /*!
@@ -451,9 +450,8 @@ QList<QContactLocalId> QContactManager::contactIds(const QList<QContactSortOrder
  */
 QList<QContactLocalId> QContactManager::contactIds(const QContactFilter& filter, const QList<QContactSortOrder>& sortOrders) const
 {
-    d->m_error = QContactManager::NoError;
-    d->m_errorMap.clear();
-    return d->m_engine->contactIds(filter, sortOrders, &d->m_error);
+    QContactManagerSyncOpErrorHolder h(this);
+    return d->m_engine->contactIds(filter, sortOrders, &h.error);
 }
 
 /*!
@@ -469,9 +467,8 @@ QList<QContactLocalId> QContactManager::contactIds(const QContactFilter& filter,
  */
 QList<QContact> QContactManager::contacts(const QList<QContactSortOrder>& sortOrders, const QContactFetchHint& fetchHint) const
 {
-    d->m_error = QContactManager::NoError;
-    d->m_errorMap.clear();
-    return d->m_engine->contacts(QContactFilter(), sortOrders, fetchHint, &d->m_error);
+    QContactManagerSyncOpErrorHolder h(this);
+    return d->m_engine->contacts(QContactFilter(), sortOrders, fetchHint, &h.error);
 }
 
 /*!
@@ -490,9 +487,8 @@ QList<QContact> QContactManager::contacts(const QList<QContactSortOrder>& sortOr
  */
 QList<QContact> QContactManager::contacts(const QContactFilter& filter, const QList<QContactSortOrder>& sortOrders, const QContactFetchHint& fetchHint) const
 {
-    d->m_error = QContactManager::NoError;
-    d->m_errorMap.clear();
-    return d->m_engine->contacts(filter, sortOrders, fetchHint, &d->m_error);
+    QContactManagerSyncOpErrorHolder h(this);
+    return d->m_engine->contacts(filter, sortOrders, fetchHint, &h.error);
 }
 
 /*!
@@ -512,9 +508,8 @@ QList<QContact> QContactManager::contacts(const QContactFilter& filter, const QL
  */
 QContact QContactManager::contact(const QContactLocalId& contactId, const QContactFetchHint& fetchHint) const
 {
-    d->m_error = QContactManager::NoError;
-    d->m_errorMap.clear();
-    return d->m_engine->contact(contactId, fetchHint, &d->m_error);
+    QContactManagerSyncOpErrorHolder h(this);
+    return d->m_engine->contact(contactId, fetchHint, &h.error);
 }
 
 /*!
@@ -537,15 +532,9 @@ QContact QContactManager::contact(const QContactLocalId& contactId, const QConta
  */
 QList<QContact> QContactManager::contacts(const QList<QContactLocalId>& localIds, const QContactFetchHint &fetchHint, QMap<int, QContactManager::Error> *errorMap) const
 {
-    d->m_error = QContactManager::NoError;
-    d->m_errorMap.clear();
+    QContactManagerSyncOpErrorHolder h(this, errorMap);
 
-    QList<QContact> retn = d->m_engine->contacts(localIds, fetchHint, &d->m_errorMap, &d->m_error);
-
-    if (errorMap)
-        *errorMap = d->m_errorMap;
-
-    return retn;
+    return d->m_engine->contacts(localIds, fetchHint, &h.errorMap, &h.error);
 }
 
 /*!
@@ -586,12 +575,12 @@ QList<QContact> QContactManager::contacts(const QList<QContactLocalId>& localIds
  */
 bool QContactManager::saveContact(QContact* contact)
 {
-    d->m_errorMap.clear();
+    QContactManagerSyncOpErrorHolder h(this);
+
     if (contact) {
-        d->m_error = QContactManager::NoError;
-        return d->m_engine->saveContact(contact, &d->m_error);
+        return d->m_engine->saveContact(contact, &h.error);
     } else {
-        d->m_error = QContactManager::BadArgumentError;
+        h.error = QContactManager::BadArgumentError;
         return false;
     }
 }
@@ -604,9 +593,8 @@ bool QContactManager::saveContact(QContact* contact)
  */
 bool QContactManager::removeContact(const QContactLocalId& contactId)
 {
-    d->m_error = QContactManager::NoError;
-    d->m_errorMap.clear();
-    return d->m_engine->removeContact(contactId, &d->m_error);
+    QContactManagerSyncOpErrorHolder h(this);
+    return d->m_engine->removeContact(contactId, &h.error);
 }
 
 /*!
@@ -626,20 +614,14 @@ bool QContactManager::removeContact(const QContactLocalId& contactId)
  */
 bool QContactManager::saveContacts(QList<QContact>* contacts, QMap<int, QContactManager::Error>* errorMap)
 {
-    bool retn = false;
-    d->m_errorMap.clear();
+    QContactManagerSyncOpErrorHolder h(this, errorMap);
 
     if (contacts) {
-        d->m_error = QContactManager::NoError;
-        retn = d->m_engine->saveContacts(contacts, &d->m_errorMap, &d->m_error);
+        return d->m_engine->saveContacts(contacts, &h.errorMap, &h.error);
     } else {
-        d->m_error =QContactManager::BadArgumentError;
+        h.error = QContactManager::BadArgumentError;
+        return false;
     }
-
-    if (errorMap)
-        *errorMap = d->m_errorMap;
-
-    return retn;
 }
 
 /*!
@@ -663,20 +645,14 @@ bool QContactManager::saveContacts(QList<QContact>* contacts, QMap<int, QContact
  */
 bool QContactManager::saveContacts(QList<QContact>* contacts, const QStringList& definitionMask, QMap<int, QContactManager::Error>* errorMap)
 {
-    bool retn = false;
-    d->m_errorMap.clear();
+    QContactManagerSyncOpErrorHolder h(this, errorMap);
 
     if (contacts) {
-        d->m_error = QContactManager::NoError;
-        retn = d->m_engine->saveContacts(contacts, definitionMask, &d->m_errorMap, &d->m_error);
+        return d->m_engine->saveContacts(contacts, definitionMask, &h.errorMap, &h.error);
     } else {
-        d->m_error =QContactManager::BadArgumentError;
+        h.error = QContactManager::BadArgumentError;
+        return false;
     }
-
-    if (errorMap)
-        *errorMap = d->m_errorMap;
-
-    return retn;
 }
 
 /*!
@@ -705,20 +681,14 @@ bool QContactManager::saveContacts(QList<QContact>* contacts, const QStringList&
  */
 bool QContactManager::removeContacts(const QList<QContactLocalId>& contactIds, QMap<int, QContactManager::Error>* errorMap)
 {
-    bool retn = false;
-    d->m_errorMap.clear();
+    QContactManagerSyncOpErrorHolder h(this, errorMap);
 
     if (!contactIds.isEmpty()) {
-        d->m_error = QContactManager::NoError;
-        retn = d->m_engine->removeContacts(contactIds, &d->m_errorMap, &d->m_error);
+        return d->m_engine->removeContacts(contactIds, &h.errorMap, &h.error);
     } else {
-        d->m_error = QContactManager::BadArgumentError;
+        h.error = QContactManager::BadArgumentError;
+        return false;
     }
-
-    if (errorMap)
-        *errorMap = d->m_errorMap;
-
-    return retn;
 }
 
 /*!
@@ -729,9 +699,8 @@ bool QContactManager::removeContacts(const QList<QContactLocalId>& contactIds, Q
  */
 QContact QContactManager::compatibleContact(const QContact& original)
 {
-    d->m_error = QContactManager::NoError;
-    d->m_errorMap.clear();
-    return d->m_engine->compatibleContact(original, &d->m_error);
+    QContactManagerSyncOpErrorHolder h(this);
+    return d->m_engine->compatibleContact(original, &h.error);
 }
 
 /*!
@@ -745,9 +714,8 @@ QContact QContactManager::compatibleContact(const QContact& original)
  */
 QString QContactManager::synthesizedContactDisplayLabel(const QContact& contact) const
 {
-    d->m_error = QContactManager::NoError;
-    d->m_errorMap.clear();
-    return d->m_engine->synthesizedDisplayLabel(contact, &d->m_error);
+    QContactManagerSyncOpErrorHolder h(this);
+    return d->m_engine->synthesizedDisplayLabel(contact, &h.error);
 }
 
 /*!
@@ -770,12 +738,11 @@ QString QContactManager::synthesizedContactDisplayLabel(const QContact& contact)
  */
 void QContactManager::synthesizeContactDisplayLabel(QContact *contact) const
 {
-    d->m_errorMap.clear();
+    QContactManagerSyncOpErrorHolder h(this);
     if (contact) {
-        d->m_error = QContactManager::NoError;
-        QContactManagerEngine::setContactDisplayLabel(contact, d->m_engine->synthesizedDisplayLabel(*contact, &d->m_error));
+        QContactManagerEngine::setContactDisplayLabel(contact, d->m_engine->synthesizedDisplayLabel(*contact, &h.error));
     } else {
-        d->m_error = QContactManager::BadArgumentError;
+        h.error = QContactManager::BadArgumentError;
     }
 }
 
@@ -792,9 +759,8 @@ void QContactManager::synthesizeContactDisplayLabel(QContact *contact) const
  */
 bool QContactManager::setSelfContactId(const QContactLocalId& contactId)
 {
-    d->m_error = QContactManager::NoError;
-    d->m_errorMap.clear();
-    return d->m_engine->setSelfContactId(contactId, &d->m_error);
+    QContactManagerSyncOpErrorHolder h(this);
+    return d->m_engine->setSelfContactId(contactId, &h.error);
 }
 
 /*!
@@ -806,9 +772,8 @@ bool QContactManager::setSelfContactId(const QContactLocalId& contactId)
  */
 QContactLocalId QContactManager::selfContactId() const
 {
-    d->m_error = QContactManager::NoError;
-    d->m_errorMap.clear();
-    return d->m_engine->selfContactId(&d->m_error);
+    QContactManagerSyncOpErrorHolder h(this);
+    return d->m_engine->selfContactId(&h.error);
 }
 
 /*!
@@ -817,9 +782,8 @@ QContactLocalId QContactManager::selfContactId() const
  */
 QList<QContactRelationship> QContactManager::relationships(const QContactId& participantId, QContactRelationship::Role role) const
 {
-    d->m_error = QContactManager::NoError;
-    d->m_errorMap.clear();
-    return d->m_engine->relationships(QString(), participantId, role, &d->m_error);
+    QContactManagerSyncOpErrorHolder h(this);
+    return d->m_engine->relationships(QString(), participantId, role, &h.error);
 }
 
 /*!
@@ -829,9 +793,8 @@ QList<QContactRelationship> QContactManager::relationships(const QContactId& par
  */
 QList<QContactRelationship> QContactManager::relationships(const QString& relationshipType, const QContactId& participantId, QContactRelationship::Role role) const
 {
-    d->m_error = QContactManager::NoError;
-    d->m_errorMap.clear();
-    return d->m_engine->relationships(relationshipType, participantId, role, &d->m_error);
+    QContactManagerSyncOpErrorHolder h(this);
+    return d->m_engine->relationships(relationshipType, participantId, role, &h.error);
 }
 
 /*!
@@ -849,12 +812,11 @@ QList<QContactRelationship> QContactManager::relationships(const QString& relati
  */
 bool QContactManager::saveRelationship(QContactRelationship* relationship)
 {
-    d->m_errorMap.clear();
+    QContactManagerSyncOpErrorHolder h(this);
     if (relationship) {
-        d->m_error = QContactManager::NoError;
-        return d->m_engine->saveRelationship(relationship, &d->m_error);
+        return d->m_engine->saveRelationship(relationship, &h.error);
     } else {
-        d->m_error =QContactManager::BadArgumentError;
+        h.error = QContactManager::BadArgumentError;
         return false;
     }
 }
@@ -866,20 +828,14 @@ bool QContactManager::saveRelationship(QContactRelationship* relationship)
  */
 bool QContactManager::saveRelationships(QList<QContactRelationship>* relationships, QMap<int, QContactManager::Error>* errorMap)
 {
-    bool retn = false;
-    d->m_errorMap.clear();
+    QContactManagerSyncOpErrorHolder h(this, errorMap);
 
     if (relationships) {
-        d->m_error = QContactManager::NoError;
-        retn = d->m_engine->saveRelationships(relationships, &d->m_errorMap, &d->m_error);
+        return d->m_engine->saveRelationships(relationships, &h.errorMap, &h.error);
     } else {
-        d->m_error =QContactManager::BadArgumentError;
+        h.error = QContactManager::BadArgumentError;
+        return false;
     }
-
-    if (errorMap)
-        *errorMap = d->m_errorMap;
-
-    return retn;
 }
 
 /*!
@@ -890,9 +846,8 @@ bool QContactManager::saveRelationships(QList<QContactRelationship>* relationshi
  */
 bool QContactManager::removeRelationship(const QContactRelationship& relationship)
 {
-    d->m_error = QContactManager::NoError;
-    d->m_errorMap.clear();
-    return d->m_engine->removeRelationship(relationship, &d->m_error);
+    QContactManagerSyncOpErrorHolder h(this);
+    return d->m_engine->removeRelationship(relationship, &h.error);
 }
 
 
@@ -903,14 +858,8 @@ bool QContactManager::removeRelationship(const QContactRelationship& relationshi
  */
 bool QContactManager::removeRelationships(const QList<QContactRelationship>& relationships, QMap<int, QContactManager::Error>* errorMap)
 {
-    d->m_error = QContactManager::NoError;
-    d->m_errorMap.clear();
-    bool retn = d->m_engine->removeRelationships(relationships, &d->m_errorMap, &d->m_error);
-
-    if (errorMap)
-        *errorMap = d->m_errorMap;
-
-    return retn;
+    QContactManagerSyncOpErrorHolder h(this, errorMap);
+    return d->m_engine->removeRelationships(relationships, &h.errorMap, &h.error);
 }
 
 /*!
@@ -919,53 +868,49 @@ bool QContactManager::removeRelationships(const QList<QContactRelationship>& rel
  */
 QMap<QString, QContactDetailDefinition> QContactManager::detailDefinitions(const QString& contactType) const
 {
-    d->m_errorMap.clear();
+    QContactManagerSyncOpErrorHolder h(this);
     if (!supportedContactTypes().contains(contactType)) {
-        d->m_error =QContactManager::InvalidContactTypeError;
+        h.error = QContactManager::InvalidContactTypeError;
         return QMap<QString, QContactDetailDefinition>();
     }
 
-    d->m_error = QContactManager::NoError;
-    return d->m_engine->detailDefinitions(contactType, &d->m_error);
+    return d->m_engine->detailDefinitions(contactType, &h.error);
 }
 
 /*! Returns the definition identified by the given \a definitionName that is valid for the contacts whose type is the given \a contactType in this store, or a default-constructed QContactDetailDefinition if no such definition exists */
 QContactDetailDefinition QContactManager::detailDefinition(const QString& definitionName, const QString& contactType) const
 {
-    d->m_errorMap.clear();
+    QContactManagerSyncOpErrorHolder h(this);
     if (!supportedContactTypes().contains(contactType)) {
-        d->m_error =QContactManager::InvalidContactTypeError;
+        h.error = QContactManager::InvalidContactTypeError;
         return QContactDetailDefinition();
     }
 
-    d->m_error = QContactManager::NoError;
-    return d->m_engine->detailDefinition(definitionName, contactType, &d->m_error);
+    return d->m_engine->detailDefinition(definitionName, contactType, &h.error);
 }
 
 /*! Persists the given definition \a def in the database, which is valid for contacts whose type is the given \a contactType.  Returns true if the definition was saved successfully, otherwise returns false */
 bool QContactManager::saveDetailDefinition(const QContactDetailDefinition& def, const QString& contactType)
 {
-    d->m_errorMap.clear();
+    QContactManagerSyncOpErrorHolder h(this);
     if (!supportedContactTypes().contains(contactType)) {
-        d->m_error =QContactManager::InvalidContactTypeError;
+        h.error = QContactManager::InvalidContactTypeError;
         return false;
     }
 
-    d->m_error = QContactManager::NoError;
-    return d->m_engine->saveDetailDefinition(def, contactType, &d->m_error);
+    return d->m_engine->saveDetailDefinition(def, contactType, &h.error);
 }
 
 /*! Removes the detail definition identified by \a definitionName from the database, which is valid for contacts whose type is the given \a contactType.  Returns true if the definition was removed successfully, otherwise returns false */
 bool QContactManager::removeDetailDefinition(const QString& definitionName, const QString& contactType)
 {
-    d->m_errorMap.clear();
+    QContactManagerSyncOpErrorHolder h(this);
     if (!supportedContactTypes().contains(contactType)) {
-        d->m_error =QContactManager::InvalidContactTypeError;
+        h.error = QContactManager::InvalidContactTypeError;
         return false;
     }
 
-    d->m_error = QContactManager::NoError;
-    return d->m_engine->removeDetailDefinition(definitionName, contactType, &d->m_error);
+    return d->m_engine->removeDetailDefinition(definitionName, contactType, &h.error);
 }
 
 /*!
