@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -61,7 +61,7 @@ CQGeoPositionInfoSourceS60::CQGeoPositionInfoSourceS60(QObject* aParent) : QGeoP
         mSupportedMethods(PositioningMethod(0)),
         mCurrentMethod(PositioningMethod(0)),
         mListSize(0),
-        mMinUpdateInterval(100),
+        mMinUpdateInterval(0),
         mStartUpdates(FALSE),
         mRegularUpdateTimedOut(FALSE),
         mModuleFlags(0)
@@ -141,10 +141,9 @@ void CQGeoPositionInfoSourceS60::ConstructL()
 
         CleanupStack::PushL(mDevStatusUpdateAO);
 
-        if (mCurrentModuleId != TUid::Null()) {
+        if (mCurrentModuleId != TUid::Null())
             mRegUpdateAO = CQMLBackendAO::NewL(this, RegularUpdate, mCurrentModuleId);
-            mRegUpdateAO->setUpdateInterval(updateInterval());
-        }
+
         CleanupStack::Pop(2);
     }
 
@@ -903,6 +902,7 @@ void CQGeoPositionInfoSourceS60::setPreferredPositioningMethods(PositioningMetho
         mCurrentModuleId = mList[index].mUid ;
         lRegLocker.unlock();
 
+
         index = checkModule(mCurrentModuleId);
 
         if (index >= 0 && index < mListSize) {
@@ -912,12 +912,15 @@ void CQGeoPositionInfoSourceS60::setPreferredPositioningMethods(PositioningMetho
             lRegLocker_interval.unlock();
         }
 
-        int value = mRegUpdateAO->setUpdateInterval(updateInterval);
-        //as the positioning module has changed,
-        //possibility of the minimumupdateinterval being changed
-        if (value != updateInterval)
-            QGeoPositionInfoSource::setUpdateInterval(value);
 
+        if (updateInterval) {
+            int value = mRegUpdateAO->setUpdateInterval(updateInterval);
+            //as the poistioning module has changed
+            //possibility of the minimumupdateinterval being changed
+            if (value != updateInterval)
+                QGeoPositionInfoSource::setUpdateInterval(value);
+
+        }
     }
 
 }
