@@ -114,7 +114,7 @@ void QOrganizerManagerData::createEngine(const QString& managerName, const QMap<
 
         /* See if we got a fast hit */
         QList<QOrganizerManagerEngineFactory*> factories = m_engines.values(builtManagerName);
-        m_error = QOrganizerManager::NoError;
+        m_lastError = QOrganizerManager::NoError;
 
         while(!found) {
             foreach (QOrganizerManagerEngineFactory* f, factories) {
@@ -122,7 +122,7 @@ void QOrganizerManagerData::createEngine(const QString& managerName, const QMap<
                 if (implementationVersion == -1 ||//no given implementation version required
                         versions.isEmpty() || //the manager engine factory does not report any version
                         versions.contains(implementationVersion)) {
-                    m_engine = f->engine(parameters, &m_error);
+                    m_engine = f->engine(parameters, &m_lastError);
                     found = true;
                     break;
                 }
@@ -141,13 +141,13 @@ void QOrganizerManagerData::createEngine(const QString& managerName, const QMap<
         // XXX remove this
         // the engine factory could lie to us, so check the real implementation version
         if (m_engine && (implementationVersion != -1 && m_engine->managerVersion() != implementationVersion)) {
-            m_error = QOrganizerManager::VersionMismatchError;
+            m_lastError = QOrganizerManager::VersionMismatchError;
             m_engine = 0;
         }
 
         if (!m_engine) {
-            if (m_error == QOrganizerManager::NoError)
-                m_error = QOrganizerManager::DoesNotExistError;
+            if (m_lastError == QOrganizerManager::NoError)
+                m_lastError = QOrganizerManager::DoesNotExistError;
             m_engine = new QOrganizerItemInvalidEngine();
         }
     }
