@@ -49,8 +49,6 @@
 #include <qgeomapoverlay.h>
 #include <qgeomaprectangleobject.h>
 #include <QPainter>
-#include <QGraphicsView>
-#include <QGraphicsScene>
 #include <QStyleOptionGraphicsItem>
 
 QTM_USE_NAMESPACE
@@ -117,20 +115,14 @@ private slots:
     void connectivityMode();
     void mapType_data();
     void mapType();
+    void shape();
     void supportedConnectivityModes_data();
     void supportedConnectivityModes();
     void supportedMapTypes_data();
     void supportedMapTypes();
     void viewport();
-    void bearing_data();
-    void bearing();
-    void maximumTilt();
-    void minimumTilt();
-    void tilting_data();
-    void tilting();
 private:
     QGeoServiceProvider* m_serviceProvider;
-    QGraphicsView *m_qgv;
     QGraphicsGeoMap* m_map;
 };
 
@@ -140,22 +132,7 @@ void tst_GeoServicesGeoMapPlugin::initTestCase()
     qRegisterMetaType<QGraphicsGeoMap::MapType> ();
     qRegisterMetaType<QGeoCoordinate> ();
     m_serviceProvider = new QGeoServiceProvider("static.geomap.test.plugin");
-
-    QGraphicsScene* scene = new QGraphicsScene(this);
-    m_qgv = new QGraphicsView(scene);
-    m_qgv->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-    m_qgv->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-    m_qgv->setVisible(true);
-    m_qgv->setInteractive(true);
-    m_qgv->resize(50, 50);
-    m_qgv->setSceneRect(QRectF(QPointF(0.0, 0.0), m_qgv->size()));
     m_map = new QGraphicsGeoMap(m_serviceProvider->mappingManager());
-    m_qgv->scene()->addItem(m_map);
-    m_map->resize(m_qgv->size());
-
-    m_qgv->show();
-    QApplication::setActiveWindow(m_qgv);
-    QTest::qWaitForWindowShown(m_qgv);
 }
 
 void tst_GeoServicesGeoMapPlugin::cleanupTestCase()
@@ -166,7 +143,6 @@ void tst_GeoServicesGeoMapPlugin::cleanupTestCase()
 
 void tst_GeoServicesGeoMapPlugin::init()
 {
-    QTest::qWait(100);
 }
 
 void tst_GeoServicesGeoMapPlugin::cleanup()
@@ -353,7 +329,7 @@ void tst_GeoServicesGeoMapPlugin::mapObjectsAtScreenPosition_data()
     QTest::newRow("Find 2 objects") << QPointF(17.0, 17.0) << 2;
     QTest::newRow("Find 2 more objects") << QPointF(17.0, 23.0) << 2;
     QTest::newRow("Find 1 object") << QPointF(30.0, 46.0) << 1;
-    QTest::newRow("Find 0 objects") << QPointF(0.0, 0.0) << 0;
+    QTest::newRow("Find 0 objects") << QPointF(60.0, 60.0) << 0;
 }
 
 // public QList<QGeoMapObject*> mapObjectsAtScreenPosition(QPointF const& screenPosition) const
@@ -362,8 +338,6 @@ void tst_GeoServicesGeoMapPlugin::mapObjectsAtScreenPosition()
     QFETCH(QPointF, screenPosition);
     QFETCH(int, expectedcount);
 
-    QSKIP("Test needs reworking", SkipAll);
-
     m_map->clearMapObjects();
 
     m_map->addMapObject(new QGeoMapRectangleObject(QGeoCoordinate(20.0, 10.0), QGeoCoordinate(10.0,
@@ -372,11 +346,9 @@ void tst_GeoServicesGeoMapPlugin::mapObjectsAtScreenPosition()
         25.0)));
     m_map->addMapObject(new QGeoMapRectangleObject(QGeoCoordinate(40.0, 10.0), QGeoCoordinate(22.0,
         20.0)));
-    m_map->addMapObject(new QGeoMapRectangleObject(QGeoCoordinate(47.0, 25.0), QGeoCoordinate(45.0,
+    m_map->addMapObject(new QGeoMapRectangleObject(QGeoCoordinate(55.0, 25.0), QGeoCoordinate(45.0,
         35.0)));
 
-    QTest::qWait(100);
-
     QSignalSpy spy0(m_map, SIGNAL( centerChanged(QGeoCoordinate const&)));
     QSignalSpy spy1(m_map, SIGNAL(connectivityModeChanged( QGraphicsGeoMap::ConnectivityMode)));
     QSignalSpy spy2(m_map, SIGNAL(mapTypeChanged( QGraphicsGeoMap::MapType)));
@@ -397,12 +369,11 @@ void tst_GeoServicesGeoMapPlugin::mapObjectsInScreenRect_data()
     QTest::addColumn<QRectF>("screenRect");
     QTest::addColumn<int>("expectedcount");
     QTest::newRow("null") << QRectF() << 0;
-    QTest::newRow("Find 1 object") << QRectF(QPointF(5.0, 5.0), QPointF(13.0, 13.0)) << 1;
-    QTest::newRow("Find 0 objects (negative rect)") << QRectF(QPointF(5.0, 13.0), QPointF(13.0, 5.0)) << 0;
-    QTest::newRow("Find 2 objects") << QRectF(QPointF(13.0, 13.0), QPointF(23.0, 21.0)) << 2;
-    QTest::newRow("Find 3 objects") << QRectF(QPointF(13.0, 13.0), QPointF(23.0, 30.0)) << 3;
-    QTest::newRow("Find 4 objects") << QRectF(QPointF(13.0, 13.0), QPointF(30.0, 60.0)) << 4;
-    QTest::newRow("Find 0 objects") << QRectF(QPointF(60.0, 60.0), QPointF(70.0, 70.0)) << 0;
+    QTest::newRow("Find 1 object") << QRectF(QPointF(5.0, 13.0), QPointF(13.0, 5.0)) << 1;
+    QTest::newRow("Find 2 objects") << QRectF(QPointF(13.0, 21.0), QPointF(23.0, 13.0)) << 2;
+    QTest::newRow("Find 3 objects") << QRectF(QPointF(13.0, 30.0), QPointF(23.0, 13.0)) << 3;
+    QTest::newRow("Find 4 objects") << QRectF(QPointF(13.0, 60.0), QPointF(30.0, 13.0)) << 4;
+    QTest::newRow("Find 0 objects") << QRectF(QPointF(60.0, 70.0), QPointF(70.0, 60.0)) << 0;
 }
 
 // public QList<QGeoMapObject*> mapObjectsInScreenRect(QRectF const& screenRect) const
@@ -411,8 +382,6 @@ void tst_GeoServicesGeoMapPlugin::mapObjectsInScreenRect()
     QFETCH(QRectF, screenRect);
     QFETCH(int, expectedcount);
 
-    QSKIP("Test needs reworking", SkipAll);
-
     m_map->clearMapObjects();
 
     m_map->addMapObject(new QGeoMapRectangleObject(QGeoCoordinate(20.0, 10.0), QGeoCoordinate(10.0,
@@ -613,30 +582,51 @@ void tst_GeoServicesGeoMapPlugin::mapType()
     QCOMPARE(m_map->mapType(), expectedMapType);
 }
 
-void tst_GeoServicesGeoMapPlugin::supportedConnectivityModes_data()
+// public QPainterPath shape() const
+void tst_GeoServicesGeoMapPlugin::shape()
 {
-    QTest::addColumn<QList<QGraphicsGeoMap::ConnectivityMode> >("supportedConnectivityModes");
-    QTest::addColumn<bool>("comparisonResult");
-    QTest::newRow("Supported connectivity modes") << (QList<QGraphicsGeoMap::ConnectivityMode> ()
-        << QGraphicsGeoMap::OfflineMode << QGraphicsGeoMap::OnlineMode
-        << QGraphicsGeoMap::HybridMode) << true;
-    QTest::newRow("Not supported connectivity modes")
-        << (QList<QGraphicsGeoMap::ConnectivityMode> () << QGraphicsGeoMap::OfflineMode
-            << QGraphicsGeoMap::NoConnectivity) << false;
-}
-
-// public QList<QGraphicsGeoMap::ConnectivityMode> supportedConnectivityModes() const
-void tst_GeoServicesGeoMapPlugin::supportedConnectivityModes()
-{
-    QFETCH(QList<QGraphicsGeoMap::ConnectivityMode> , supportedConnectivityModes);
-    QFETCH(bool, comparisonResult);
+    QPainterPath shape;
 
     QSignalSpy spy0(m_map, SIGNAL( centerChanged(QGeoCoordinate const&)));
     QSignalSpy spy1(m_map, SIGNAL(connectivityModeChanged( QGraphicsGeoMap::ConnectivityMode)));
     QSignalSpy spy2(m_map, SIGNAL(mapTypeChanged( QGraphicsGeoMap::MapType)));
     QSignalSpy spy3(m_map, SIGNAL(zoomLevelChanged(qreal)));
 
-    QCOMPARE((m_map->supportedConnectivityModes() == supportedConnectivityModes), comparisonResult);
+    QCOMPARE(m_map->shape(), shape);
+
+    QCOMPARE(spy0.count(), 0);
+    QCOMPARE(spy1.count(), 0);
+    QCOMPARE(spy2.count(), 0);
+    QCOMPARE(spy3.count(), 0);
+}
+
+void tst_GeoServicesGeoMapPlugin::supportedConnectivityModes_data()
+{
+    QTest::addColumn<QList<QGraphicsGeoMap::ConnectivityMode> >("supportedConnectivityModes");
+    QTest::addColumn<bool>("expecttofail");
+    QTest::newRow("Supported connectivity modes") << (QList<QGraphicsGeoMap::ConnectivityMode> ()
+        << QGraphicsGeoMap::OfflineMode << QGraphicsGeoMap::OnlineMode
+        << QGraphicsGeoMap::HybridMode) << false;
+    QTest::newRow("Not supported connectivity modes")
+        << (QList<QGraphicsGeoMap::ConnectivityMode> () << QGraphicsGeoMap::OfflineMode
+            << QGraphicsGeoMap::NoConnectivity) << true;
+}
+
+// public QList<QGraphicsGeoMap::ConnectivityMode> supportedConnectivityModes() const
+void tst_GeoServicesGeoMapPlugin::supportedConnectivityModes()
+{
+    QFETCH(QList<QGraphicsGeoMap::ConnectivityMode> , supportedConnectivityModes);
+    QFETCH(bool, expecttofail);
+
+    QSignalSpy spy0(m_map, SIGNAL( centerChanged(QGeoCoordinate const&)));
+    QSignalSpy spy1(m_map, SIGNAL(connectivityModeChanged( QGraphicsGeoMap::ConnectivityMode)));
+    QSignalSpy spy2(m_map, SIGNAL(mapTypeChanged( QGraphicsGeoMap::MapType)));
+    QSignalSpy spy3(m_map, SIGNAL(zoomLevelChanged(qreal)));
+
+    if (expecttofail)
+        QEXPECT_FAIL("", "Expecting the compare to fail", Continue);
+
+    QCOMPARE(m_map->supportedConnectivityModes(), supportedConnectivityModes);
 
     QCOMPARE(spy0.count(), 0);
     QCOMPARE(spy1.count(), 0);
@@ -647,26 +637,29 @@ void tst_GeoServicesGeoMapPlugin::supportedConnectivityModes()
 void tst_GeoServicesGeoMapPlugin::supportedMapTypes_data()
 {
     QTest::addColumn<QList<QGraphicsGeoMap::MapType> >("supportedMapTypes");
-    QTest::addColumn<bool>("comparisonResult");
+    QTest::addColumn<bool>("expecttofail");
     QTest::newRow("Supported map types") << (QList<QGraphicsGeoMap::MapType> ()
         << QGraphicsGeoMap::StreetMap << QGraphicsGeoMap::SatelliteMapDay
-        << QGraphicsGeoMap::TerrainMap) << true;
+        << QGraphicsGeoMap::TerrainMap) << false;
     QTest::newRow("Not supported map types") << (QList<QGraphicsGeoMap::MapType> ()
-        << QGraphicsGeoMap::StreetMap << QGraphicsGeoMap::SatelliteMapNight) << false;
+        << QGraphicsGeoMap::StreetMap << QGraphicsGeoMap::SatelliteMapNight) << true;
 }
 
 // public QList<QGraphicsGeoMap::MapType> supportedMapTypes() const
 void tst_GeoServicesGeoMapPlugin::supportedMapTypes()
 {
     QFETCH(QList<QGraphicsGeoMap::MapType> , supportedMapTypes);
-    QFETCH(bool, comparisonResult);
+    QFETCH(bool, expecttofail);
 
     QSignalSpy spy0(m_map, SIGNAL( centerChanged(QGeoCoordinate const&)));
     QSignalSpy spy1(m_map, SIGNAL(connectivityModeChanged( QGraphicsGeoMap::ConnectivityMode)));
     QSignalSpy spy2(m_map, SIGNAL(mapTypeChanged( QGraphicsGeoMap::MapType)));
     QSignalSpy spy3(m_map, SIGNAL(zoomLevelChanged(qreal)));
 
-    QCOMPARE((m_map->supportedMapTypes() == supportedMapTypes), comparisonResult);
+    if (expecttofail)
+        QEXPECT_FAIL("", "Expecting the compare to fail", Continue);
+
+    QCOMPARE(m_map->supportedMapTypes(), supportedMapTypes);
 
     QCOMPARE(spy0.count(), 0);
     QCOMPARE(spy1.count(), 0);
@@ -682,7 +675,7 @@ void tst_GeoServicesGeoMapPlugin::viewport()
     QSignalSpy spy2(m_map, SIGNAL(mapTypeChanged( QGraphicsGeoMap::MapType)));
     QSignalSpy spy3(m_map, SIGNAL(zoomLevelChanged(qreal)));
 
-    QCOMPARE(m_map->viewport(), QGeoBoundingBox(QGeoCoordinate(50,0), QGeoCoordinate(0,50)));
+    QCOMPARE(m_map->viewport(), QGeoBoundingBox());
 
     QCOMPARE(spy0.count(), 0);
     QCOMPARE(spy1.count(), 0);
@@ -756,123 +749,6 @@ void tst_GeoServicesGeoMapPlugin::minimumZoomLevel()
     QCOMPARE(spy3.count(), 0);
 }
 
-// public qreal maximumTilt() const
-void tst_GeoServicesGeoMapPlugin::maximumTilt()
-{
-    QSignalSpy spy0(m_map, SIGNAL( centerChanged(QGeoCoordinate const&)));
-    QSignalSpy spy1(m_map, SIGNAL(connectivityModeChanged( QGraphicsGeoMap::ConnectivityMode)));
-    QSignalSpy spy2(m_map, SIGNAL(mapTypeChanged( QGraphicsGeoMap::MapType)));
-    QSignalSpy spy3(m_map, SIGNAL(zoomLevelChanged(qreal)));
-    QSignalSpy spy4(m_map, SIGNAL(bearingChanged(qreal)));
-    QSignalSpy spy5(m_map, SIGNAL(tiltChanged(qreal)));
-
-    QCOMPARE(m_map->maximumTilt(), qreal(90.0));
-
-    QCOMPARE(spy0.count(), 0);
-    QCOMPARE(spy1.count(), 0);
-    QCOMPARE(spy2.count(), 0);
-    QCOMPARE(spy3.count(), 0);
-    QCOMPARE(spy4.count(), 0);
-    QCOMPARE(spy5.count(), 0);
-}
-
-// public qreal minimumTilt() const
-void tst_GeoServicesGeoMapPlugin::minimumTilt()
-{
-    QSignalSpy spy0(m_map, SIGNAL( centerChanged(QGeoCoordinate const&)));
-    QSignalSpy spy1(m_map, SIGNAL(connectivityModeChanged( QGraphicsGeoMap::ConnectivityMode)));
-    QSignalSpy spy2(m_map, SIGNAL(mapTypeChanged( QGraphicsGeoMap::MapType)));
-    QSignalSpy spy3(m_map, SIGNAL(zoomLevelChanged(qreal)));
-    QSignalSpy spy4(m_map, SIGNAL(bearingChanged(qreal)));
-    QSignalSpy spy5(m_map, SIGNAL(tiltChanged(qreal)));
-
-    QCOMPARE(m_map->minimumTilt(), qreal(0.0));
-
-    QCOMPARE(spy0.count(), 0);
-    QCOMPARE(spy1.count(), 0);
-    QCOMPARE(spy2.count(), 0);
-    QCOMPARE(spy3.count(), 0);
-    QCOMPARE(spy4.count(), 0);
-    QCOMPARE(spy5.count(), 0);
-}
-
-void tst_GeoServicesGeoMapPlugin::bearing_data()
-{
-    QTest::addColumn<qreal>("bearing");
-    QTest::addColumn<int>("signalcount");
-    QTest::addColumn<qreal>("expectedBearing");
-    QTest::newRow("under minimum") << qreal(-1.0) << 0 << qreal(0.0);
-    QTest::newRow("valid 45") << qreal(45.0) << 1 << qreal(45.0);
-    QTest::newRow("null") << qreal(0.0) << 1 << qreal(0.0);
-    QTest::newRow("maximum") << qreal(360.0) << 1 << qreal(360.0);
-    QTest::newRow("valid 180") << qreal(180.0) << 1 << qreal(180.0);
-    QTest::newRow("over maximum") << qreal(540.0) << 1 << qreal(360.0);
-}
-
-// public void setBearing(qreal bearing)
-// public qreal bearing() const
-void tst_GeoServicesGeoMapPlugin::bearing()
-{
-    QFETCH(qreal, bearing);
-    QFETCH(int, signalcount);
-    QFETCH(qreal, expectedBearing);
-
-    QSignalSpy spy0(m_map, SIGNAL( centerChanged(QGeoCoordinate const&)));
-    QSignalSpy spy1(m_map, SIGNAL(connectivityModeChanged( QGraphicsGeoMap::ConnectivityMode)));
-    QSignalSpy spy2(m_map, SIGNAL(mapTypeChanged( QGraphicsGeoMap::MapType)));
-    QSignalSpy spy3(m_map, SIGNAL(zoomLevelChanged(qreal)));
-    QSignalSpy spy4(m_map, SIGNAL(bearingChanged(qreal)));
-    QSignalSpy spy5(m_map, SIGNAL(tiltChanged(qreal)));
-
-    m_map->setBearing(bearing);
-
-    QCOMPARE(spy0.count(), 0);
-    QCOMPARE(spy1.count(), 0);
-    QCOMPARE(spy2.count(), 0);
-    QCOMPARE(spy3.count(), 0);
-    QCOMPARE(spy4.count(), signalcount);
-    QCOMPARE(spy5.count(), 0);
-    QCOMPARE(m_map->bearing(), expectedBearing);
-}
-
-void tst_GeoServicesGeoMapPlugin::tilting_data()
-{
-    QTest::addColumn<qreal>("tilt");
-    QTest::addColumn<int>("signalcount");
-    QTest::addColumn<qreal>("expectedTilt");
-    QTest::newRow("valid") << qreal(45.0) << 1 << qreal(45.0);
-    QTest::newRow("null") << qreal(0.0) << 1 << qreal(0.0);
-    QTest::newRow("under minimum") << qreal(-1.0) << 0 << qreal(0.0);
-    QTest::newRow("valid maximum") << qreal(90.0) << 1 << qreal(90.0);
-    QTest::newRow("over maximum") << qreal(180.0) << 0 << qreal(90.0);
-}
-
-// public void setTilting(qreal tilt)
-// public qreal tilting() const
-void tst_GeoServicesGeoMapPlugin::tilting()
-{
-    QFETCH(qreal, tilt);
-    QFETCH(int, signalcount);
-    QFETCH(qreal, expectedTilt);
-
-    QSignalSpy spy0(m_map, SIGNAL( centerChanged(QGeoCoordinate const&)));
-    QSignalSpy spy1(m_map, SIGNAL(connectivityModeChanged( QGraphicsGeoMap::ConnectivityMode)));
-    QSignalSpy spy2(m_map, SIGNAL(mapTypeChanged( QGraphicsGeoMap::MapType)));
-    QSignalSpy spy3(m_map, SIGNAL(zoomLevelChanged(qreal)));
-    QSignalSpy spy4(m_map, SIGNAL(bearingChanged(qreal)));
-    QSignalSpy spy5(m_map, SIGNAL(tiltChanged(qreal)));
-
-    m_map->setTilt(tilt);
-
-    QCOMPARE(spy0.count(), 0);
-    QCOMPARE(spy1.count(), 0);
-    QCOMPARE(spy2.count(), 0);
-    QCOMPARE(spy3.count(), 0);
-    QCOMPARE(spy4.count(), 0);
-    QCOMPARE(spy5.count(), signalcount);
-    QCOMPARE(m_map->tilt(), expectedTilt);
-}
-
 QTEST_MAIN( tst_GeoServicesGeoMapPlugin)
 #include "tst_geoservicesgeomapplugin.moc"
 
