@@ -7,11 +7,11 @@
 ** This file is part of the Qt Mobility Components.
 **
 ** $QT_BEGIN_LICENSE:LGPL$
-** Commercial Usage
-** Licensees holding valid Qt Commercial licenses may use this file in 
-** accordance with the Qt Commercial License Agreement provided with
-** the Software or, alternatively, in accordance with the terms
-** contained in a written agreement between you and Nokia.
+** No Commercial Usage
+** This file contains pre-release code and may not be distributed.
+** You may use this file in accordance with the terms and conditions
+** contained in the Technology Preview License Agreement accompanying
+** this package.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
@@ -25,16 +25,16 @@
 ** rights.  These rights are described in the Nokia Qt LGPL Exception
 ** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3.0 as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.  Please review the following information to
-** ensure the GNU General Public License version 3.0 requirements will be
-** met: http://www.gnu.org/copyleft/gpl.html.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+**
+**
+**
+**
+**
+**
+**
 **
-** If you are unsure which license is appropriate for your use, please
-** contact the sales department at qt-sales@nokia.com.
 ** $QT_END_LICENSE$
 **
 ****************************************************************************/
@@ -87,6 +87,7 @@ private:
     QRemoteServiceRegister::Entry uniqueEntry2;
 
     QObject *connectToService(const QString &serviceName);
+    bool servicePublished;
 };
 
 bool mySecurityFilterFunction(const void *p)
@@ -159,6 +160,8 @@ void tst_QRemoteServiceRegister::initTestCase()
 
     valid = uniqueEntry2.isValid();
     QVERIFY(valid == true);
+
+    servicePublished = false;
 }
 
 void tst_QRemoteServiceRegister::cleanupTestCase()
@@ -221,6 +224,7 @@ void tst_QRemoteServiceRegister::checkPublish()
 {
     //publish the registered services
     serviceRegister->publishEntries("qt_sfw_example_rsr_unittest");
+    servicePublished = true;
 
     //check instantiation type
     //- default value
@@ -239,17 +243,32 @@ Q_DECLARE_METATYPE(QRemoteServiceRegister::Entry);
 void tst_QRemoteServiceRegister::tst_instanceClosed()
 {
     qRegisterMetaType<QRemoteServiceRegister::Entry>("QRemoteServiceRegister::Entry");
+<<<<<<< HEAD
 
     serviceRegister->setSecurityFilter(alwaysPass);
     QSignalSpy spy(serviceRegister,SIGNAL(instanceClosed(QRemoteServiceRegister::Entry)));
+=======
+    if(!servicePublished)
+        serviceRegister->publishEntries("qt_sfw_example_rsr_unittest");
+
+    serviceRegister->setSecurityFilter(alwaysPass);
+    QSignalSpy spy(serviceRegister,SIGNAL(instanceClosed(QRemoteServiceRegister::Entry)));
+    QSignalSpy spyAll(serviceRegister,SIGNAL(allInstancesClosed()));
+>>>>>>> 4920213d2dee904e984cb40afe58a67f9a52e9e8
 
     QObject *o = connectToService("RSRExampleService");
     QVERIFY(o);
 
     delete o;
 
+<<<<<<< HEAD
     qDebug() << "Spy Count-------- " << spy.count();
     QVERIFY (spy.count() > 0);
+=======
+    QCOMPARE(spy.count(), 1);
+    QCOMPARE(spyAll.count(), 1);
+
+>>>>>>> 4920213d2dee904e984cb40afe58a67f9a52e9e8
 }
 
 QObject *tst_QRemoteServiceRegister::connectToService(const QString &serviceName)
@@ -257,8 +276,13 @@ QObject *tst_QRemoteServiceRegister::connectToService(const QString &serviceName
     QServiceManager manager;
 
     QList<QServiceInterfaceDescriptor> list = manager.findInterfaces(serviceName);
+<<<<<<< HEAD
     if (list.isEmpty()) {
         qWarning() << "Couldn't find service" << serviceName;
+=======
+    if (list.isEmpty()) {        
+        qWarning() << "Couldn't find service" << serviceName << manager.findServices("qt_sfw_example_rsr_unittest");
+>>>>>>> 4920213d2dee904e984cb40afe58a67f9a52e9e8
         return 0;
     }
 
